Installation
============

Using pip
---------

Pip is the recommended method of installing *echelle*.

.. code-block:: bash

    pip install echelle

From Source
-----------

.. code-block:: bash

    git clone --recursive https://github.com/danhey/echelle.git
    cd echelle
    python setup.py install

Requirements
------------

By default, *echelle* requires `Bokeh` and `matplotlib` to be installed.

    